@@ -1,7 +1,7 @@
 from copy import deepcopy
 import json
 import matplotlib.pyplot as plt
-from tqdm import tqdm
+from tqdm.auto import tqdm
 import random
 import os
 import numpy as np
@@ -70,11 +70,15 @@ def generate_bootstrap_curves(
         )
 
         for cat_id in lls:
-            plt.semilogx(lls[cat_id], nlls[cat_id], "-", alpha=0.05)
-            collected_frocs["lls"].get(cat_id, []).append(lls[cat_id])
-            collected_frocs["nlls"].get(cat_id, []).append(nlls[cat_id])
+            if collected_frocs['lls'].get(cat_id, None) is None:
+                collected_frocs["lls"] = {cat_id : []}
+            if collected_frocs['nlls'].get(cat_id, None) is None:
+                collected_frocs["nlls"] = {cat_id : []}
 
-        collected_frocs.append((lls, nlls))
+        for cat_id in lls:
+            plt.semilogx(nlls[cat_id], lls[cat_id], "b--", alpha=0.15)
+            collected_frocs["lls"][cat_id].append(lls[cat_id])
+            collected_frocs["nlls"][cat_id].append(nlls[cat_id])
 
     mean_froc_lls = {}
     mean_froc_nlls = {}
@@ -94,16 +98,20 @@ def generate_bootstrap_curves(
         )
 
     mean_froc_curve = {}
+
+
+
     for cat_id in collected_frocs["lls"]:
         mean_froc_curve[cat_id] = np.stack(
             (mean_froc_nlls[cat_id], mean_froc_lls[cat_id]), axis=-1
         )
-
-        plt.semilogx(mean_froc_curve[cat_id][:, 0], mean_froc_curve[cat_id][:, 1], "x-")
-
+        plt.semilogx(mean_froc_curve[cat_id][:, 0], mean_froc_curve[cat_id][:, 1], "bx-",
+        label='mean')
     plt.xlabel("FP/image")
     plt.ylabel("Sensitivity")
 
+    plt.legend(loc='upper left')
+
     os.remove("/tmp/tmp_bootstrap_gt.json")
     os.remove("/tmp/tmp_bootstrap_pred.json")
 
